@@ -2,6 +2,8 @@ from .order import OrderType, OrderStatus, OrderSide, Order
 from .response_message import CryptodotcomResponseMessage
 from .request import CryptodotcomRequestMessage
 from .enhanced_websocket import EnhancedWebsocket, EnhancedWebsocketBehaviorSubject
+from .user_balance import UserBalance, PositionBalance
+from .trade import Trade
 
 __all__ = [
     "Order",
@@ -12,4 +14,7 @@ __all__ = [
     "CryptodotcomRequestMessage",
     "EnhancedWebsocket",
     "EnhancedWebsocketBehaviorSubject",
+    "UserBalance",
+    "PositionBalance",
+    "Trade",
 ]
